# chronos

Chronos: Innovation Algebra & Trust SDK
=======================================

A minimal, composable Python SDK for modeling change events, trust graphs, and innovation landscapes. Includes algebraic change sets, trust propagation, Riemannian geometry helpers, and a master equation integrator.

## Features
- **Change Algebra**: Immutable, timestamped change events and sets with union/intersection/difference, composition, inversion, and state evolution.
- **Trust Graphs**: Weighted directed trust networks with path aggregation and logistic update law (requires `networkx`).
- **Manifold Geometry**: Minimal Riemannian metric/geodesic/curvature helpers (requires `numpy`).
- **Navigator**: Lightweight forward-Euler integrator for arbitrary vector fields.

## Installation

With [UV](https://github.com/astral-sh/uv):
```sh
uv pip install chronos
```

Or with pip:
```sh
pip install chronos
```

## Usage

### Change Algebra
```python
from chronos import ChangeEvent, ChangeSet, change_set

# Create events
c1 = ChangeEvent(timestamp=1.0, state_before=0, state_after=1)
c2 = ChangeEvent(timestamp=2.0, state_before=1, state_after=2)

# Create a set
cs = ChangeSet([c1, c2])

# Algebraic ops
cs2 = cs.inverse()
cs3 = cs.union(cs2)
```

### Trust Graphs
```python
from chronos import TrustGraph
T = TrustGraph()
T.set_trust('alice', 'bob', 0.8)
T.update_trust('alice', 'bob', delta=0.1)
trust = T.get_trust('alice', 'bob')
```

### Manifold Geometry
```python
from chronos import Metric, geodesic, curvature
import numpy as np
metric = Metric(lambda x: np.eye(len(x)))
path = geodesic(metric, np.array([0,0]), np.array([1,1]))
curv = curvature(metric, np.array([0,0]))
```

### Navigator
```python
from chronos import Navigator
import numpy as np
nav = Navigator(lambda x: -x)
traj = nav.integrate(np.array([1.0, 0.0]), steps=10)
```

## Requirements
- Python 3.9+
- `networkx` (for trust graphs)
- `numpy` (for manifold & navigator)

---
MIT License. See source for details.